<template>
    <div class="system-add-menu-container">
        <el-dialog :title="title" v-model="isShowRectifyDialog" width="600px" :close-on-click-modal="false">
            <el-form :model="rectifyForm" :rules="rectifyFormRules" ref="rectifyFormRef" size="default" label-width="120px">
                <el-row :gutter="35">
                    <el-col :xs="24" :sm="24" :md="24" :lg="24" :xl="24" class="mb20">
                        <el-form-item label="整改说明" prop="rectifyInfo">
                            <el-input class="input-add" type="textarea" :rows="2" v-model.trim="rectifyForm.rectifyInfo" placeholder="请输入整改说明" clearable></el-input>
                        </el-form-item>
                    </el-col>
                    <el-col :xs="24" :sm="24" :md="24" :lg="24" :xl="24" class="mb20">
                        <el-form-item label="整改时间" prop="applyTime">
                            <el-date-picker type="datetime" :disabled-date="disabledDate" value-format="YYYY-MM-DD HH:mm:ss" class="input-add" v-model="rectifyForm.applyTime" placeholder="请选择整改时间" clearable> </el-date-picker>
                        </el-form-item>
                    </el-col>
                </el-row>
            </el-form>
            <template #footer>
                <span class="dialog-footer">
                    <el-button @click="isShowRectifyDialog = !isShowRectifyDialog" size="default">取 消</el-button>
                    <el-button type="primary" @click="submitRectify" v-throttle size="default">确 定</el-button>
                </span>
            </template>
        </el-dialog>
        <el-dialog :title="title" v-model="isShowDelayDialog" width="600px" :close-on-click-modal="false">
            <el-form :model="delayForm" :rules="delayFormRules" ref="rectifyFormRef" size="default" label-width="120px">
                <el-row :gutter="35">
                    <el-col :xs="24" :sm="24" :md="24" :lg="24" :xl="24" class="mb20">
                        <el-form-item label="延期说明" prop="timeOutDesc">
                            <el-input class="input-add" type="textarea" :rows="2" v-model.trim="delayForm.timeOutDesc" placeholder="请输入延期说明" clearable></el-input>
                        </el-form-item>
                    </el-col>
                    <el-col :xs="24" :sm="24" :md="24" :lg="24" :xl="24" class="mb20">
                        <el-form-item label="整改期限" prop="rectifyTime">
                            <el-date-picker type="datetime" value-format="YYYY-MM-DD HH:mm:ss" class="input-add" v-model="delayForm.rectifyTime" placeholder="请选择整改期限" clearable> </el-date-picker>
                        </el-form-item>
                    </el-col>
                </el-row>
            </el-form>
            <template #footer>
                <span class="dialog-footer" v-show="disabled">
                    <el-button @click="isShowDelayDialog = !isShowDelayDialog" size="default">取 消</el-button>
                    <el-button type="primary" @click="submitDelay" v-throttle size="default">确 定</el-button>
                </span>
            </template>
        </el-dialog>
        <el-dialog :title="title" v-model="isShowCheckInfoDialog" width="600px" :close-on-click-modal="false">
            <el-form :model="checkInfoForm" ref="checkFormRef" size="default" label-width="120px">
                <el-row :gutter="35">
                    <el-col :xs="24" :sm="24" :md="24" :lg="24" :xl="24" class="mb20">
                        <el-form-item label="整改内容说明" prop="rectifyDesc">
                            <el-input class="input-add" :disabled="!disabled" type="textarea" :rows="2" v-model.trim="checkInfoForm.rectifyDesc" readonly></el-input>
                        </el-form-item>
                    </el-col>
                    <el-col :xs="24" :sm="24" :md="24" :lg="24" :xl="24" class="mb20">
                        <el-form-item label="整改类型" prop="rectifyType">
                            <el-select class="input-add" :disabled="!disabled" v-model="checkInfoForm.rectifyType" readonly>
                                <el-option v-for="item in rectifyTypeList" :key="item.id" :label="item.name" :value="item.id"></el-option>
                            </el-select>
                        </el-form-item>
                    </el-col>
                    <el-col :xs="24" :sm="24" :md="24" :lg="24" :xl="24" class="mb20">
                        <el-form-item label="整改部门" prop="rectifyDepId">
                            <el-cascader @change="achieveUserList" :disabled="!disabled" :options="departmentList" :props="{ emitPath: false, checkStrictly: true, value: 'depId', label: 'depName' }" placeholder="请选择部门" clearable filterable class="input-add" v-model="checkInfoForm.rectifyDepId" readonly> </el-cascader>
                        </el-form-item>
                    </el-col>

                    <el-col :xs="24" :sm="24" :md="24" :lg="24" :xl="24" class="mb20">
                        <el-form-item label="整改责任人" prop="liablePersonId">
                            <el-select class="input-add" :disabled="!disabled" v-model="checkInfoForm.liablePersonId" clearable filterable readonly>
                                <el-option v-for="item in userList" :key="item.uid" :label="item.username" :value="item.uid"></el-option>
                            </el-select>
                        </el-form-item>
                    </el-col>

                    <el-col :xs="24" :sm="24" :md="24" :lg="24" :xl="24" class="mb20">
                        <el-form-item label="整改资金" prop="dangerResult">
                            <el-input class="input-add" :disabled="!disabled" type="number" v-model="checkInfoForm.cost" readonly> </el-input>
                        </el-form-item>
                    </el-col>
                    <el-col :xs="24" :sm="24" :md="24" :lg="24" :xl="24" class="mb20" v-show="personTime">
                        <el-form-item label="创建人" prop="location">
                            <el-input class="input-add" :disabled="!disabled" v-model.trim="checkInfoForm.createByUserName" placeholder="请输入区域位置"></el-input>
                        </el-form-item>
                    </el-col>
                    <el-col :xs="24" :sm="24" :md="24" :lg="24" :xl="24" class="mb20" v-show="personTime">
                        <el-form-item label="创建时间" prop="location">
                            <el-input class="input-add" :disabled="!disabled" v-model.trim="checkInfoForm.gmtCreate" placeholder="请输入区域位置"></el-input>
                        </el-form-item>
                    </el-col>
                    <el-col :xs="24" :sm="24" :md="24" :lg="24" :xl="24" class="mb20" v-show="personTime">
                        <el-form-item label="最后修改人" prop="location">
                            <el-input class="input-add" :disabled="!disabled" v-model.trim="checkInfoForm.lastEditUserName" placeholder="请输入区域位置"></el-input>
                        </el-form-item>
                    </el-col>
                    <el-col :xs="24" :sm="24" :md="24" :lg="24" :xl="24" class="mb20" v-show="personTime">
                        <el-form-item label="最后修改时间" prop="location">
                            <el-input class="input-add" :disabled="!disabled" v-model.trim="checkInfoForm.gmtModitify" placeholder="请输入区域位置"></el-input>
                        </el-form-item>
                    </el-col>
                </el-row>
            </el-form>
        </el-dialog>
    </div>
</template>

<script lang="ts">
import { getUserByDepartment } from '/@/assets/methods';

interface stateType {
    disabled: Boolean;
    personTime: Boolean;
    isShowRectifyDialog: Boolean;
    isShowDelayDialog: Boolean;
    isShowCheckInfoDialog: Boolean;
    rectifyForm: {
        id: number | null;
        dangerManagerId: number | null;
        rectifyInfo: string | null;
        applyTime: string | null;
    };
    delayForm: {
        id: number | null;
        dangerManagerId: number | null;
        rectifyTime: string | null;
        timeOutDesc: string | null;
    };
    disabledDate: any;
    rangeTime: any;
    title: string;
    departmentList: [];
    userList: [];
    rectifyTypeList: Array<rectifyTypeState>;
    rectifyFormRules: {};
    delayFormRules: {};
    checkInfoForm: {
        rectifyDepId: number | null;
        liablePersonId: number | null;
    };
}
interface rectifyTypeState {
    regionType: string;
    id: number;
}

import { reactive, toRefs, ref } from 'vue';
import { ElMessage } from 'element-plus';
import { hiddenRectifyApi } from '/@/api/doublePreventSystem/rectify';
export default {
    name: 'rectifyDialog',
    setup(props: any, context: any) {
        const rectifyFormRef = ref();
        const state = reactive<stateType>({
            title: '',
            disabled: false,
            personTime: false,
            rectifyTypeList: [],
            departmentList: [],
            userList: [],
            isShowCheckInfoDialog: false,
            checkInfoForm: {
                rectifyDepId: null,
                liablePersonId: null
            },
            isShowDelayDialog: false,
            isShowRectifyDialog: false,
            rectifyForm: {
                id: null,
                dangerManagerId: null,
                rectifyInfo: null,
                applyTime: null
            },
            disabledDate: (time: any) => {
                const r = new Date().getTime();
                return time.getTime() > new Date().getTime();
            },
            rangeTime: () => {
                return '15:15:14';
            },
            delayForm: {
                id: null,
                dangerManagerId: null,
                rectifyTime: null,
                timeOutDesc: null
            },
            rectifyFormRules: {
                rectifyInfo: [{ required: true, message: '请填写整改说明', trigger: 'blur' }],
                applyTime: [{ required: true, message: '请选择整改时间', trigger: 'change' }]
            },
            delayFormRules: {
                timeOutDesc: [{ required: true, message: '请填写延期说明', trigger: 'blur' }],
                rectifyTime: [{ required: true, message: '请选择整改期限', trigger: 'change' }]
            }
        });

        //打开模态框
        const openRectifyDialog = async (type: string, value: object, departmentList: []) => {
            state.departmentList = departmentList;
            if (type === '延期') {
                state.title = '延期';
                state.disabled = true;
                state.personTime = false;
                state.isShowDelayDialog = true;
                const delayForm = JSON.parse(JSON.stringify(value));
                state.delayForm.id = delayForm.id;
                state.delayForm.dangerManagerId = delayForm.dangerManagerId;
                state.delayForm.timeOutDesc = null;
                state.delayForm.rectifyTime = null;
            } else if (type === '查看') {
                state.title = '查看';
                state.personTime = true;
                state.isShowCheckInfoDialog = true;
                state.checkInfoForm.rectifyDepId = JSON.parse(JSON.stringify(value)).rectifyDepId;
                await achieveUserList();
                state.checkInfoForm = JSON.parse(JSON.stringify(value));
            } else {
                state.disabled = true;
                state.personTime = false;
                state.title = '整改';
                state.isShowRectifyDialog = true;
                const rectifyForm = JSON.parse(JSON.stringify(value));
                state.rectifyForm.id = rectifyForm.id;
                state.rectifyForm.dangerManagerId = rectifyForm.dangerManagerId;
                state.rectifyForm.rectifyInfo = null;
                state.rectifyForm.applyTime = null;
            }
        };

        //提交整改
        const submitRectify = async () => {
            rectifyFormRef.value.validate(async (valid: Boolean) => {
                if (valid) {
                    let res = await hiddenRectifyApi().submitHiddenRectify(state.rectifyForm);
                    if (res.data.code === '200') {
                        ElMessage({
                            type: 'success',
                            message: '整改提交成功',
                            duration: 2000
                        });
                        state.isShowRectifyDialog = false;
                        context.emit('refreshRectify');
                    } else {
                        ElMessage({
                            type: 'warning',
                            message: res.data.msg
                        });
                    }
                } else {
                    ElMessage({
                        type: 'warning',
                        message: '请完善基本信息'
                    });
                }
            });
        };

        //提交延期
        const submitDelay = async () => {
            rectifyFormRef.value.validate(async (valid: Boolean) => {
                if (valid) {
                    let res = await hiddenRectifyApi().delayHiddenRectifyTime(state.delayForm);
                    if (res.data.code === '200') {
                        ElMessage({
                            type: 'success',
                            message: '隐患延期成功',
                            duration: 2000
                        });
                        state.isShowDelayDialog = false;
                        context.emit('refreshRectify');
                    } else {
                        ElMessage({
                            type: 'warning',
                            message: res.data.msg
                        });
                    }
                } else {
                    ElMessage({
                        type: 'warning',
                        message: '请完善基本信息'
                    });
                }
            });
        };

        const achieveUserList = async () => {
            state.checkInfoForm.liablePersonId = null;
            const user: unknown = await getUserByDepartment(state.checkInfoForm.rectifyDepId);
            state.userList = user as [];
        };

        return {
            ...toRefs(state),
            rectifyFormRef,
            submitDelay,
            achieveUserList,
            submitRectify,
            openRectifyDialog
        };
    }
};
</script>

<style scoped></style>
